@@ -8,9 +8,9 @@ module ActiveJob
 
   module VERSION
     MAJOR = 7
-    MINOR = 1
-    TINY  = 6
-    PRE   = nil
+    MINOR = 2
+    TINY  = 2
+    PRE   = "1"
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
